==> haskell-monad-logger-0.3.31-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-logger
version: 0.3.31
id: monad-logger-0.3.31-8nIPhDITODnHw8fQb75Tkt
key: monad-logger-0.3.31-8nIPhDITODnHw8fQb75Tkt
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/monad-logger#readme
synopsis: A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>
category: System
abi: cc271d755d7b49635d6cbaaa9ef3554d
exposed: True
exposed-modules:
    Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules: Paths_monad_logger
import-dirs: /usr/lib/ghc-8.6.5/site-local/monad-logger-0.3.31
library-dirs: /usr/lib/ghc-8.6.5/site-local/monad-logger-0.3.31
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/monad-logger-0.3.31
hs-libraries: HSmonad-logger-0.3.31-8nIPhDITODnHw8fQb75Tkt
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-KLNDZz0JwjY8UxgeaedHmp
    conduit-extra-1.3.4-D0NpH8QgZ19ARuWPauoeRr
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    fast-logger-3.0.0-GjpcBX1YPXdAemBNe1iSUl
    lifted-base-0.2.3.12-B4DztZYcWo5FX71P7R1jj6
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA mtl-2.2.2
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 stm-2.5.0.0
    stm-chans-3.0.0.4-HYjkOAxusm59Rsr7teGCcb template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock
haddock-html: /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-logger-0.3.31-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-logger
version: 0.3.31
id: monad-logger-0.3.31-FAgxhuWyaNn1UqfvDickvC
key: monad-logger-0.3.31-FAgxhuWyaNn1UqfvDickvC
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/monad-logger#readme
synopsis: A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>
category: System
abi: cff77ea70ffee2dc724894255693b675
exposed: True
exposed-modules:
    Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules: Paths_monad_logger
import-dirs: /usr/lib/ghc-8.6.5/site-local/monad-logger-0.3.31
library-dirs: /usr/lib/ghc-8.6.5/site-local/monad-logger-0.3.31
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/monad-logger-0.3.31
hs-libraries: HSmonad-logger-0.3.31-FAgxhuWyaNn1UqfvDickvC
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-7rushQ980336tJPFaKI7Kn
    conduit-extra-1.3.4-Hpz3g3HVeraCM2NDO7b1k4
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    fast-logger-3.0.0-GjpcBX1YPXdAemBNe1iSUl
    lifted-base-0.2.3.12-B4DztZYcWo5FX71P7R1jj6
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA mtl-2.2.2
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 stm-2.5.0.0
    stm-chans-3.0.0.4-HYjkOAxusm59Rsr7teGCcb template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock
haddock-html: /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
